7fd86d24ec58a7e91f2abcc696bc7c108a866400
max
  Tue Mar 20 11:43:40 2012 -0700
changed table names in sql files as hiram code review, redmine #7363
diff --git src/hg/lib/pubsBlat.sql src/hg/lib/pubsBlat.sql
index 404e815..f68ecc3 100644
--- src/hg/lib/pubsBlat.sql
+++ src/hg/lib/pubsBlat.sql
@@ -1,19 +1,21 @@
-#Text to Genome project feature table, in bed12+ format, additional field seqIds
-CREATE TABLE `t2g` (
+#publications blat feature table, in bed12+ format, additional field seqIds and seqRanges
+CREATE TABLE `pubsBlat` (
   `chrom` varchar(255) NOT NULL, # chromosome
   `chromStart` int(10) unsigned NOT NULL, # start position on chromosome
   `chromEnd` int(10) unsigned NOT NULL, # end position on chromosome
-  `name` varchar(255) NOT NULL, #name of feature
+  `name` varchar(255) NOT NULL, # internal articleId, article that matches here
   `score` int(10) unsigned NOT NULL, # score of feature
   `strand` char(1) NOT NULL, # strand of feature
   `thickStart` int(10) unsigned NOT NULL, # start of exons
   `thickEnd` int(10) unsigned NOT NULL, #end of exons
   `reserved` int(10) unsigned NOT NULL, # no clue
   `blockCount` int(10) unsigned NOT NULL, # number of blocks
   `blockSizes` longblob NOT NULL, # size of blocks
   `chromStarts` longblob NOT NULL, # A comma-separated list of block starts
-  `seqIds` longblob NOT NULL, # comma-separated list of sequenceIds used to generate this feature
+  `tSeqTypes` varchar(255) NOT NULL, # comma-seq list of matching sequence db (g=genome, p=protein, c=cDNA)
+  `seqIds` blob NOT NULL, # comma-separated list of matching seqIds
+  `seqRanges` blob NOT NULL, # ranges start-end on sequence that matched, one for each seqId 
   KEY `name` (`name`(16)),
   KEY `chrom` (`chrom`(6)),
   KEY `chromStartAndName` (`chrom`(6), chromStart, name)
 );